@@ -186,7 +186,7 @@ use PPIx::Regexp::Util qw{
 use Scalar::Util qw{ refaddr };
 use Text::Tabs ();
 
-our $VERSION = '0.075';
+our $VERSION = '0.077';
 
 =head2 new
 
@@ -454,7 +454,6 @@ any objects specified are removed from the cache.
 
 sub can_be_quantified { return; }
 
-
 =head2 capture_names
 
  foreach my $name ( $re->capture_names() ) {
@@ -568,7 +567,6 @@ sub extract_regexps {
     );
 }
 
-
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -921,7 +919,8 @@ is again supported.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -929,7 +928,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
