@@ -58,12 +58,11 @@ use PPIx::Regexp::Constant qw{
 
 use constant KEEP_EXPLANATION	=> 'In s///, keep everything before the \\K';
 
-our $VERSION = '0.076';
+our $VERSION = '0.077';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
-
 my @braced_assertions = (
     [ qr< \\ [bB] [{] (?: g | gcb | wb | sb ) [}] >smx, '5.021009' ],
     [ qr< \\ [bB] [{] (?: lb ) [}] >smx, '5.023007' ],
@@ -225,7 +224,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -233,7 +233,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
