@@ -36,22 +36,22 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.073';
+our $VERSION = '0.077';
 
-{
-    my $expl = 'Match subexpression without backtracking';
-    __PACKAGE__->__setup_class( {
-	    '?>'		=> {
-		expl	=> $expl,
-		intro	=> '5.005',
-	    },
-	    '*atomic:'	=> {
-		expl	=> $expl,
-		intro 	=>'5.027009',
-	    },
-	}
-    );
-}
+use constant EXPL	=> 'Match subexpression without backtracking';
+
+use constant DEF	=> {
+    '?>'		=> {
+	expl	=> EXPL,
+	intro	=> '5.005',
+    },
+    '*atomic:'	=> {
+	expl	=> EXPL,
+	intro 	=>'5.027009',
+    },
+};
+
+__PACKAGE__->__setup_class();
 
 1;
 
@@ -60,7 +60,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -68,7 +69,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
