@@ -23,7 +23,7 @@ our @EXPORT_OK = qw{
     __to_ordinal_en
 };
 
-our $VERSION = '0.075';
+our $VERSION = '0.077';
 
 sub is_ppi_regexp_element {
     my ( $elem ) = @_;
@@ -165,7 +165,6 @@ representing its ordinal in English. For example
 
 =cut
 
-
 =head1 SEE ALSO
 
 L<Params::Util|Params::Util>, which I recommend, but in the case of
@@ -173,11 +172,11 @@ C<PPIx::Regexp> I did not want to introduce a dependency on an XS module
 when all I really wanted was the function of that module's
 C<_INSTANCE()> subroutine.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -185,7 +184,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
